==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/PrintPreview/ts/PrintPreview_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Frame</name>
    <message>
        <source>Columns:</source>
        <translation type="obsolete">Colonne:</translation>
    </message>
    <message>
        <source>Rows:</source>
        <translation type="obsolete">Righe:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Chiudi</translation>
    </message>
</context>
<context>
    <name>PrintPreview</name>
    <message>
        <location filename="../PrintPreview.js" line="+161"/>
        <source>Drag to move paper</source>
        <translation>Trascinare per spostare la carta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location line="+383"/>
        <source>Export to PDF</source>
        <translation>Esporta PDF</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Exporting to %1...</source>
        <translation>Esportazione in %1...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Export complete: %1</source>
        <translation>Esportazione completata: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Export failed (cannot open file for writing): %1</source>
        <translation>Esportazione fallita (Impossibile aprire il file): %1</translation>
    </message>
    <message>
        <location filename="../PrintPreviewInit.js" line="+2"/>
        <source>Print Pre&amp;view</source>
        <translation>&amp;Anteprima di Stampa</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Preview how current drawing would be printed</source>
        <translation>Visualizzare un&apos;anteprima del disegno corrente sarebbe da stampare</translation>
    </message>
    <message>
        <location filename="../PrintPreview.ui" line="+17"/>
        <source>Close Print Preview</source>
        <translation>Chiudere l&apos;anteprima di stampa</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Export as PDF...</source>
        <translation>Esporta PDF...</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Scale:</source>
        <translation>Scala:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Drawing Scale</source>
        <translation>Disegno in scala</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Move Paper Position</source>
        <translation>Cambiare la posizione della carta</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Auto fit drawing to page(s)</source>
        <translation>Adatta disegno alla pagina(s)</translation>
    </message>
    <message>
        <location line="+76"/>
        <source>Auto zoom to page</source>
        <translation>Zoom Automatico per pagina</translation>
    </message>
    <message>
        <source>Auto fit pages to drawing</source>
        <translation type="obsolete">Montare le pagine al disegno</translation>
    </message>
    <message>
        <location line="-65"/>
        <source>Auto Center</source>
        <translation>Auto centro</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Portrait</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <source>PageOrientation</source>
        <translation type="obsolete">PageOrientation</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Landscape</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation type="obsolete">Pagina singola</translation>
    </message>
    <message>
        <source>Multiple Pages</source>
        <translation type="obsolete">Più pagine</translation>
    </message>
    <message>
        <source>Auto zoom to page(s)</source>
        <translation type="obsolete">Zoom Automatico per pagina(s)</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Full Color Mode</source>
        <translation>Colore</translation>
    </message>
    <message>
        <source>ColorMode</source>
        <translation type="obsolete">ColorMode</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Grayscale Mode</source>
        <translation>Scala di grigio</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Black / White Mode</source>
        <translation>Bianco / Nero</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Show Paper Borders</source>
        <translation>Mostra bordi della carta</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Print Crop Marks</source>
        <translation>Stampa indicatori di ritaglio</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Show More Options</source>
        <translation>Mostra più opzioni</translation>
    </message>
    <message>
        <location line="-291"/>
        <source>Print...</source>
        <translation>Stampa...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/PrintPreview/ts/PrintPreview_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Frame</name>
    <message>
        <source>Columns:</source>
        <translation type="obsolete">Colonne:</translation>
    </message>
    <message>
        <source>Rows:</source>
        <translation type="obsolete">Righe:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Chiudi</translation>
    </message>
</context>
<context>
    <name>PrintPreview</name>
    <message>
        <location filename="../PrintPreview.js" line="+232"/>
        <source>Drag to move paper</source>
        <translation>Trascinare per spostare la carta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location line="+405"/>
        <source>Export to PDF</source>
        <translation>Esporta PDF</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Exporting to %1...</source>
        <translation>Esportazione in %1...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Export complete: %1</source>
        <translation>Esportazione completata: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Export failed (cannot open file for writing): %1</source>
        <translation>Esportazione fallita (Impossibile aprire il file): %1</translation>
    </message>
    <message>
        <location filename="../PrintPreviewInit.js" line="+2"/>
        <source>Print Pre&amp;view</source>
        <translation>&amp;Anteprima di stampa</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Preview how current drawing would be printed</source>
        <translation>Visualizzare un&apos;anteprima del disegno corrente sarebbe da stampare</translation>
    </message>
    <message>
        <location filename="../PrintPreview.ui" line="+17"/>
        <source>Close Print Preview</source>
        <translation>Chiudere l&apos;anteprima di stampa</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Export as PDF...</source>
        <translation>Esporta PDF...</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Scale:</source>
        <translation>Scala:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Drawing Scale</source>
        <translation>Disegno in scala</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Move Paper Position</source>
        <translation>Cambiare la posizione della carta</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Auto fit drawing to page(s)</source>
        <translation>Adatta disegno alla pagina(s)</translation>
    </message>
    <message>
        <location line="+76"/>
        <source>Auto zoom to page</source>
        <translation>Zoom Automatico per pagina</translation>
    </message>
    <message>
        <source>Auto fit pages to drawing</source>
        <translation type="obsolete">Montare le pagine al disegno</translation>
    </message>
    <message>
        <location line="-65"/>
        <source>Auto Center</source>
        <translation>Auto centro</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Portrait</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <source>PageOrientation</source>
        <translation type="obsolete">PageOrientation</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Landscape</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation type="obsolete">Pagina singola</translation>
    </message>
    <message>
        <source>Multiple Pages</source>
        <translation type="obsolete">Più pagine</translation>
    </message>
    <message>
        <source>Auto zoom to page(s)</source>
        <translation type="obsolete">Zoom Automatico per pagina(s)</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Full Color Mode</source>
        <translation>Colore</translation>
    </message>
    <message>
        <source>ColorMode</source>
        <translation type="obsolete">ColorMode</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Grayscale Mode</source>
        <translation>Scala di grigio</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Black / White Mode</source>
        <translation>Bianco / Nero</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Show Paper Borders</source>
        <translation>Mostra bordi della carta</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Print Crop Marks</source>
        <translation>Stampa indicatori di ritaglio</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Show More Options</source>
        <translation>Mostra più opzioni</translation>
    </message>
    <message>
        <location line="-291"/>
        <source>Print...</source>
        <translation>Stampa...</translation>
    </message>
</context>
</TS>
